
From: Tom Rini <trini@kernel.crashing.org>

The following patch against 2.6.10-rc1 fixes the brain damage that was
found in the CPM2 uart driver.  Previously, if 8250 was configured in, it
would use one set of numbers (which at the time didn't conflict with
anything, but have since been officially given to the Motorola i.MX driver)
and if 8250 wasn't in, it would masquerade as it.  The following switches
us over to 204/46...49 (Which is still unclaimed).  I don't know whose tree
this should go in, however..

Signed-off-by: Tom Rini <trini@kernel.crashing.org>

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/Documentation/devices.txt          |    7 +++++++
 25-akpm/drivers/serial/cpm_uart/cpm_uart.h |    7 +------
 2 files changed, 8 insertions(+), 6 deletions(-)

diff -puN Documentation/devices.txt~fix-cpm2-uart-driver-device-number-brain-damage Documentation/devices.txt
--- 25/Documentation/devices.txt~fix-cpm2-uart-driver-device-number-brain-damage	Mon Nov  1 16:43:10 2004
+++ 25-akpm/Documentation/devices.txt	Mon Nov  1 16:43:10 2004
@@ -2758,6 +2758,10 @@ Your cooperation is appreciated.
 		 43 = /dev/ttySMX2		Motorola i.MX - port 2
 		 44 = /dev/ttyMM0		Marvell MPSC - port 0
 		 45 = /dev/ttyMM1		Marvell MPSC - port 1
+		 46 = /dev/ttyCPM0		PPC CPM (SCC or SMC) - port 0
+		    ...
+		 49 = /dev/ttyCPM5		PPC CPM (SCC or SMC) - port 5
+
 
 205 char	Low-density serial ports (alternate device)
 		  0 = /dev/culu0		Callout device for ttyLU0
@@ -2786,6 +2790,9 @@ Your cooperation is appreciated.
 		 41 = /dev/ttySMX0		Callout device for ttySMX0
 		 42 = /dev/ttySMX1		Callout device for ttySMX1
 		 43 = /dev/ttySMX2		Callout device for ttySMX2
+		 46 = /dev/cucpm0		Callout device for ttyCPM0
+		    ...
+		 49 = /dev/cucpm5		Callout device for ttyCPM5
 
 206 char	OnStream SC-x0 tape devices
 		  0 = /dev/osst0		First OnStream SCSI tape, mode 0
diff -puN drivers/serial/cpm_uart/cpm_uart.h~fix-cpm2-uart-driver-device-number-brain-damage drivers/serial/cpm_uart/cpm_uart.h
--- 25/drivers/serial/cpm_uart/cpm_uart.h~fix-cpm2-uart-driver-device-number-brain-damage	Mon Nov  1 16:43:10 2004
+++ 25-akpm/drivers/serial/cpm_uart/cpm_uart.h	Mon Nov  1 16:43:10 2004
@@ -17,13 +17,8 @@
 #include "cpm_uart_cpm1.h"
 #endif
 
-#ifndef CONFIG_SERIAL_8250
-#define SERIAL_CPM_MAJOR	TTY_MAJOR
-#define SERIAL_CPM_MINOR	64
-#else
 #define SERIAL_CPM_MAJOR	204
-#define SERIAL_CPM_MINOR	42
-#endif
+#define SERIAL_CPM_MINOR	46
 
 #define IS_SMC(pinfo) 		(pinfo->flags & FLAG_SMC)
 #define IS_DISCARDING(pinfo)	(pinfo->flags & FLAG_DISCARDING)
_
